@@ -1,6 +1,6 @@
 /*
     orzcharset
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -150,9 +150,8 @@ static void
 orz_charset_init (OrzCharset *charset)
 {
 #if GTK_CHECK_VERSION(2,4,0)
-  charset->store = gtk_list_store_new (1, G_TYPE_STRING);
   gtk_combo_box_set_model (GTK_COMBO_BOX (charset),
-                                            GTK_TREE_MODEL (charset->store));
+                    GTK_TREE_MODEL (gtk_list_store_new (1, G_TYPE_STRING)));
   gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (charset), 0);
   g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (charset))),
                     "activate", G_CALLBACK (orz_charset_activate), charset);
@@ -232,23 +231,24 @@ orz_charset_get_candidate (OrzCharset *charset)
 {
   gchar *candidate = NULL;
   gint i;
-#if ! GTK_CHECK_VERSION(2,4,0)
+#if GTK_CHECK_VERSION(2,4,0)
+  GtkTreeModel *model;
+#else /* not GTK_CHECK_VERSION(2,4,0) */
   GList *glist;
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
 
   if (!charset)
     return NULL;
 #if GTK_CHECK_VERSION(2,4,0)
-  for (i = gtk_tree_model_iter_n_children
-                    (GTK_TREE_MODEL (charset->store), NULL) - 1; i >= 0; i--)
+  model = gtk_combo_box_get_model (GTK_COMBO_BOX (charset));
+  for (i = gtk_tree_model_iter_n_children (model, NULL) - 1; i >= 0; i--)
     {
       gchar *str, *tmp;
       GtkTreeIter iter;
 
-      gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (charset->store),
-                                                            &iter, NULL, i);
-      gtk_tree_model_get (GTK_TREE_MODEL (charset->store), &iter, 0, &tmp, -1);
-      str = g_strjoin (",", tmp, candidate, NULL);
+      gtk_tree_model_iter_nth_child (model, &iter, NULL, i);
+      gtk_tree_model_get (model, &iter, 0, &tmp, -1);
+      str = g_strconcat (tmp, ",", candidate, NULL);
       g_free (tmp);
       g_free (candidate);
       candidate = str;
@@ -259,8 +259,8 @@ orz_charset_get_candidate (OrzCharset *charset)
     {
       gchar *str;
 
-      str = g_strjoin (",", gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
-                    (GTK_BIN (g_list_nth_data (glist, i))))), candidate, NULL);
+      str = g_strconcat (gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
+            (GTK_BIN (g_list_nth_data (glist, i))))), ",", candidate, NULL);
       g_free (candidate);
       candidate = str;
     }
@@ -281,10 +281,16 @@ orz_charset_add_candidate (OrzCharset *charset,
   gboolean result = TRUE;
   gchar **str;
   gint i;
+#if GTK_CHECK_VERSION(2,4,0)
+  GtkListStore *store;
+#endif /* GTK_CHECK_VERSION(2,4,0) */
 
   if (!charset || !candidate)
     return FALSE;
   str = g_strsplit (candidate, ",", 0);
+#if GTK_CHECK_VERSION(2,4,0)
+  store = GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (charset)));
+#endif /* GTK_CHECK_VERSION(2,4,0) */
   for (i = 0; str[i]; i++)
     if (charuty_is_valid (str[i]))
       {
@@ -294,27 +300,26 @@ orz_charset_add_candidate (OrzCharset *charset,
         GtkTreeIter iter;
 
         for (j = gtk_tree_model_iter_n_children
-                    (GTK_TREE_MODEL (charset->store), NULL) - 1; j >= 0; j--)
+                            (GTK_TREE_MODEL (store), NULL) - 1; j >= 0; j--)
           {
             gchar *tmp;
             gint cmp;
 
-            gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (charset->store),
+            gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                                             &iter, NULL, j);
-            gtk_tree_model_get (GTK_TREE_MODEL (charset->store), &iter,
-                                                                0, &tmp, -1);
-            cmp = g_strcasecmp (tmp, str[i]);
+            gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, 0, &tmp, -1);
+            cmp = g_ascii_strcasecmp (tmp, str[i]);
             g_free (tmp);
             if (cmp == 0)
               {
-                gtk_list_store_remove (charset->store, &iter);
+                gtk_list_store_remove (store, &iter);
                 j--;
               }
             if (cmp <= 0)
               break;
           }
-        gtk_list_store_insert (charset->store, &iter, j + 1);
-        gtk_list_store_set (charset->store, &iter, 0, str[i], -1);
+        gtk_list_store_insert (store, &iter, j + 1);
+        gtk_list_store_set (store, &iter, 0, str[i], -1);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
         GList *glist;
         GtkWidget *item;
@@ -325,7 +330,7 @@ orz_charset_add_candidate (OrzCharset *charset,
           {
             gint cmp;
 
-            cmp = g_strcasecmp (gtk_label_get_text (GTK_LABEL
+            cmp = g_ascii_strcasecmp (gtk_label_get_text (GTK_LABEL
                 (gtk_bin_get_child (GTK_BIN (g_list_nth_data (glist, j))))),
                                                                     str[i]);
             if (cmp == 0)
@@ -364,9 +369,15 @@ orz_charset_remove_candidate (OrzCharset *charset,
   gboolean result = TRUE;
   gchar **str;
   gint i;
+#if GTK_CHECK_VERSION(2,4,0)
+  GtkListStore *store;
+#endif /* GTK_CHECK_VERSION(2,4,0) */
 
   if (!charset)
     return FALSE;
+#if GTK_CHECK_VERSION(2,4,0)
+  store = GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (charset)));
+#endif /* GTK_CHECK_VERSION(2,4,0) */
   if (candidate)
     {
       str = g_strsplit (candidate, ",", 0);
@@ -376,21 +387,20 @@ orz_charset_remove_candidate (OrzCharset *charset,
 
 #if GTK_CHECK_VERSION(2,4,0)
           for (j = gtk_tree_model_iter_n_children
-                    (GTK_TREE_MODEL (charset->store), NULL) - 1; j >= 0; j--)
+                            (GTK_TREE_MODEL (store), NULL) - 1; j >= 0; j--)
             {
               gchar *tmp;
               gint cmp;
               GtkTreeIter iter;
 
-              gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (charset->store),
+              gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                                             &iter, NULL, j);
-              gtk_tree_model_get (GTK_TREE_MODEL (charset->store), &iter,
-                                                                0, &tmp, -1);
-              cmp = g_strcasecmp (tmp, str[i]);
+              gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, 0, &tmp, -1);
+              cmp = g_ascii_strcasecmp (tmp, str[i]);
               g_free (tmp);
               if (cmp == 0)
                 {
-                  gtk_list_store_remove (charset->store, &iter);
+                  gtk_list_store_remove (store, &iter);
                   break;
                 }
             }
@@ -400,8 +410,9 @@ orz_charset_remove_candidate (OrzCharset *charset,
           glist = gtk_container_children
                                 (GTK_CONTAINER (GTK_COMBO (charset)->list));
           for (j = g_list_length (glist) - 1; j >= 0; j--)
-            if (g_strcasecmp (gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
-                        (GTK_BIN (g_list_nth_data (glist, j))))), str[i]) == 0)
+            if (g_ascii_strcasecmp (gtk_label_get_text (GTK_LABEL
+                (gtk_bin_get_child (GTK_BIN (g_list_nth_data (glist, j))))),
+                                                                str[i]) == 0)
               {
                 gtk_list_clear_items (GTK_LIST (GTK_COMBO (charset)->list),
                                                                     j, j + 1);
@@ -417,7 +428,7 @@ orz_charset_remove_candidate (OrzCharset *charset,
   else
     {
 #if GTK_CHECK_VERSION(2,4,0)
-      gtk_list_store_clear (charset->store);
+      gtk_list_store_clear (store);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
       gtk_list_clear_items (GTK_LIST (GTK_COMBO (charset)->list), 0, G_MAXINT);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
