@@ -1,6 +1,6 @@
 /*
     orzwinmenu
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -118,8 +118,12 @@ orz_winmenu_add (OrzMdi     *mdi,
 
       glist = gtk_container_get_children (GTK_CONTAINER (winmenu->menu_shell));
       length = g_list_length (glist);
+#if GLIB_CHECK_VERSION(2,6,0)
+      label = g_filename_display_name (orz_mdi_get_file (mdi, page_num));
+#else /* not GLIB_CHECK_VERSION(2,6,0) */
       label = g_filename_to_utf8 (orz_mdi_get_file (mdi, page_num), -1,
                                                             NULL, NULL, NULL);
+#endif /* not GLIB_CHECK_VERSION(2,6,0) */
       menu_item = glist ? gtk_radio_menu_item_new_with_label_from_widget
                                     (GTK_RADIO_MENU_ITEM (glist->data), label)
                         : gtk_radio_menu_item_new_with_label (NULL, label);
@@ -205,8 +209,12 @@ orz_winmenu_change (OrzMdi     *mdi,
       GtkWidget *child;
 
       child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (mdi), page_num);
+#if GLIB_CHECK_VERSION(2,6,0)
+      label = g_filename_display_name (orz_mdi_get_file (mdi, page_num));
+#else /* not GLIB_CHECK_VERSION(2,6,0) */
       label = g_filename_to_utf8 (orz_mdi_get_file (mdi, page_num), -1,
                                                             NULL, NULL, NULL);
+#endif /* not GLIB_CHECK_VERSION(2,6,0) */
       for (i = g_list_length (winmenu->glist) - 1; i >= 0; i--)
         {
           GtkWidget *menu_item;
@@ -566,7 +574,7 @@ orz_winmenu_set_mdi (OrzWinmenu *winmenu,
 void
 orz_winmenu_set_menu (OrzWinmenu *winmenu,
                       GtkWidget   *menu_shell,
-                      gint         position)
+                      const gint   position)
 {
   if (winmenu)
     {
