@@ -151,10 +151,17 @@ mm_dialog_init (MmDialog *dialog)
   /* ja:ボタン */
   dialog->abort_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
                                         GTK_STOCK_STOP, GTK_RESPONSE_REJECT);
+#ifdef G_OS_WIN32
+  dialog->ok_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
+                                        GTK_STOCK_OK, GTK_RESPONSE_OK);
+  dialog->cancel_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
+                                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+#else /* not G_OS_WIN32 */
   dialog->cancel_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
   dialog->ok_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
                                         GTK_STOCK_OK, GTK_RESPONSE_OK);
+#endif /* not G_OS_WIN32 */
   /* ja:リスト */
   dialog->list = mm_list_new ();
   /* ja:スクロールウインドウ */
