@@ -210,7 +210,7 @@ main (int   argc,
   locale = g_build_filename (dirname, "locale", NULL);
   g_free (dirname);
 # ifdef G_OS_WIN32
-  if (!fileio_isfile (locale))
+  if (!g_file_test (locale, G_FILE_TEST_EXISTS))
     {
       g_free (locale);
       locale = g_win32_get_package_installation_subdirectory
